@@ -8,6 +8,6 @@ from snmp.engine import Engine
 from snmp.message import MessageProcessingModel
 from snmp.security.levels import *
 
-SNMPv1  = MessageProcessingModel.SNMPv1.value
-SNMPv2c = MessageProcessingModel.SNMPv2c.value
-SNMPv3  = MessageProcessingModel.SNMPv3.value
+SNMPv1  = MessageProcessingModel.SNMPv1
+SNMPv2c = MessageProcessingModel.SNMPv2c
+SNMPv3  = MessageProcessingModel.SNMPv3
