@@ -57,6 +57,7 @@ class Request(RequestHandle):
         self.response = response
         self.event.set()
 
+    # Always update self.nextRefresh right before calling this method
     def reallySend(self):
         self.manager.sendPdu(self.pdu, self, self.community)
 
@@ -65,17 +66,19 @@ class Request(RequestHandle):
             return None
 
         now = time.time()
-        delta = self.nextRefresh - now
+        timeToNextRefresh = self.nextRefresh - now
 
-        if delta <= 0.0:
+        if timeToNextRefresh <= 0.0:
             if self.expiration <= now:
                 return None
 
-            self.nextRefresh += math.ceil(-delta / self.period) * self.period
+            # Calculating it like this mitigates over-delay
+            periodsElapsed = math.ceil(-timeToNextRefresh / self.period)
+            self.nextRefresh += periodsElapsed * self.period
             self.reallySend()
             return 0.0
         else:
-            return delta
+            return timeToNextRefresh
 
     def send(self):
         now = time.time()
